@@ -26,7 +26,7 @@ import (
 
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/afero"
-	"go.k6.io/k6/lib/metrics"
+	"go.k6.io/k6/metrics"
 )
 
 // InitEnvironment contains properties that can be accessed by Go code executed
