@@ -32,27 +32,27 @@ import (
 
 	"go.k6.io/k6/js/common"
 	"go.k6.io/k6/js/modules"
-	"go.k6.io/k6/stats"
+	"go.k6.io/k6/metrics"
 )
 
 type Metric struct {
-	metric *stats.Metric
+	metric *metrics.Metric
 	vu     modules.VU
 }
 
 // ErrMetricsAddInInitContext is error returned when adding to metric is done in the init context
 var ErrMetricsAddInInitContext = common.NewInitContextError("Adding to metrics in the init context is not supported")
 
-func (mi *ModuleInstance) newMetric(call goja.ConstructorCall, t stats.MetricType) (*goja.Object, error) {
+func (mi *ModuleInstance) newMetric(call goja.ConstructorCall, t metrics.MetricType) (*goja.Object, error) {
 	initEnv := mi.vu.InitEnv()
 	if initEnv == nil {
 		return nil, errors.New("metrics must be declared in the init context")
 	}
 	rt := mi.vu.Runtime()
 	c, _ := goja.AssertFunction(rt.ToValue(func(name string, isTime ...bool) (*goja.Object, error) {
-		valueType := stats.Default
+		valueType := metrics.Default
 		if len(isTime) > 0 && isTime[0] {
-			valueType = stats.Time
+			valueType = metrics.Time
 		}
 		m, err := initEnv.Registry.NewMetric(name, t, valueType)
 		if err != nil {
@@ -135,8 +135,8 @@ func (m Metric) add(v goja.Value, addTags ...map[string]string) (bool, error) {
 		}
 	}
 
-	sample := stats.Sample{Time: time.Now(), Metric: m.metric, Value: vfloat, Tags: stats.IntoSampleTags(&tags)}
-	stats.PushIfNotDone(m.vu.Context(), state.Samples, sample)
+	sample := metrics.Sample{Time: time.Now(), Metric: m.metric, Value: vfloat, Tags: metrics.IntoSampleTags(&tags)}
+	metrics.PushIfNotDone(m.vu.Context(), state.Samples, sample)
 	return true, nil
 }
 
@@ -178,7 +178,7 @@ func (mi *ModuleInstance) Exports() modules.Exports {
 
 // XCounter is a counter constructor
 func (mi *ModuleInstance) XCounter(call goja.ConstructorCall, rt *goja.Runtime) *goja.Object {
-	v, err := mi.newMetric(call, stats.Counter)
+	v, err := mi.newMetric(call, metrics.Counter)
 	if err != nil {
 		common.Throw(rt, err)
 	}
@@ -187,7 +187,7 @@ func (mi *ModuleInstance) XCounter(call goja.ConstructorCall, rt *goja.Runtime)
 
 // XGauge is a gauge constructor
 func (mi *ModuleInstance) XGauge(call goja.ConstructorCall, rt *goja.Runtime) *goja.Object {
-	v, err := mi.newMetric(call, stats.Gauge)
+	v, err := mi.newMetric(call, metrics.Gauge)
 	if err != nil {
 		common.Throw(rt, err)
 	}
@@ -196,7 +196,7 @@ func (mi *ModuleInstance) XGauge(call goja.ConstructorCall, rt *goja.Runtime) *g
 
 // XTrend is a trend constructor
 func (mi *ModuleInstance) XTrend(call goja.ConstructorCall, rt *goja.Runtime) *goja.Object {
-	v, err := mi.newMetric(call, stats.Trend)
+	v, err := mi.newMetric(call, metrics.Trend)
 	if err != nil {
 		common.Throw(rt, err)
 	}
@@ -205,7 +205,7 @@ func (mi *ModuleInstance) XTrend(call goja.ConstructorCall, rt *goja.Runtime) *g
 
 // XRate is a rate constructor
 func (mi *ModuleInstance) XRate(call goja.ConstructorCall, rt *goja.Runtime) *goja.Object {
-	v, err := mi.newMetric(call, stats.Rate)
+	v, err := mi.newMetric(call, metrics.Rate)
 	if err != nil {
 		common.Throw(rt, err)
 	}
