@@ -23,7 +23,6 @@ package modules
 import (
 	"context"
 	"fmt"
-	"reflect"
 	"strings"
 	"sync"
 
@@ -82,18 +81,6 @@ type Instance interface {
 	Exports() Exports
 }
 
-func getInterfaceMethods() []string {
-	var t Instance
-	T := reflect.TypeOf(&t).Elem()
-	result := make([]string, T.NumMethod())
-
-	for i := range result {
-		result[i] = T.Method(i).Name
-	}
-
-	return result
-}
-
 // VU gives access to the currently executing VU to a module Instance
 type VU interface {
 	// Context return the context.Context about the current VU
