@@ -18,6 +18,9 @@
  *
  */
 
+// Package output contains the interfaces that k6 outputs (and output
+// extensions) have to implement, as well as some helpers to make their
+// implementation and management easier.
 package output
 
 import (
@@ -29,8 +32,7 @@ import (
 	"github.com/spf13/afero"
 
 	"go.k6.io/k6/lib"
-	"go.k6.io/k6/lib/metrics"
-	"go.k6.io/k6/stats"
+	"go.k6.io/k6/metrics"
 )
 
 // Params contains all possible constructor parameters an output may need.
@@ -50,6 +52,8 @@ type Params struct {
 	ExecutionPlan  []lib.ExecutionStep
 }
 
+// TODO: make v2 with buffered channels?
+
 // An Output abstracts the process of funneling samples to an external storage
 // backend, such as a file or something like an InfluxDB instance.
 //
@@ -69,7 +73,7 @@ type Output interface {
 	// method is never called concurrently, so do not do anything blocking here
 	// that might take a long time. Preferably, just use the SampleBuffer or
 	// something like it to buffer metrics until they are flushed.
-	AddMetricSamples(samples []stats.SampleContainer)
+	AddMetricSamples(samples []metrics.SampleContainer)
 
 	// Flush all remaining metrics and finalize the test run.
 	Stop() error
@@ -79,7 +83,7 @@ type Output interface {
 // thresholds before it can be started.
 type WithThresholds interface {
 	Output
-	SetThresholds(map[string]stats.Thresholds)
+	SetThresholds(map[string]metrics.Thresholds)
 }
 
 // WithTestRunStop is an output that can stop the Engine mid-test, interrupting
